Index: webrtc/modules/audio_coding/neteq/decision_logic.h |
diff --git a/webrtc/modules/audio_coding/neteq/decision_logic.h b/webrtc/modules/audio_coding/neteq/decision_logic.h |
index 008655d1a2bb930d6f184ca394e2648b31c670fd..66c940d7a6b10aa065d6658fa9da5926e5d38a49 100644 |
--- a/webrtc/modules/audio_coding/neteq/decision_logic.h |
+++ b/webrtc/modules/audio_coding/neteq/decision_logic.h |
@@ -26,7 +26,7 @@ class DelayManager; |
class Expand; |
class PacketBuffer; |
class SyncBuffer; |
-struct RTPHeader; |
+struct Packet; |
// This is the base class for the decision tree implementations. Derived classes |
// must implement the method GetDecisionSpecialized(). |
@@ -66,19 +66,18 @@ class DecisionLogic { |
// Returns the operation that should be done next. |sync_buffer| and |expand| |
// are provided for reference. |decoder_frame_length| is the number of samples |
// obtained from the last decoded frame. If there is a packet available, the |
// packet header should be supplied in |packet_header|; otherwise it should |
// be NULL. The mode resulting form the last call to NetEqImpl::GetAudio is |
// supplied in |prev_mode|. If there is a DTMF event to play, |play_dtmf| |
// should be set to true. The output variable |reset_decoder| will be set to |
// true if a reset is required; otherwise it is left unchanged (i.e., it can |
// remain true if it was true before the call). |
// This method end with calling GetDecisionSpecialized to get the actual |
// return value. |
Operations GetDecision(const SyncBuffer& sync_buffer, |
const Expand& expand, |
size_t decoder_frame_length, |
- const RTPHeader* packet_header, |
+ const Packet* next_packet, |
Modes prev_mode, |
bool play_dtmf, |
size_t generated_noise_samples, |
@@ -124,18 +123,17 @@ class DecisionLogic { |
// Returns the operation that should be done next. |sync_buffer| and |expand| |
// are provided for reference. |decoder_frame_length| is the number of samples |
// obtained from the last decoded frame. If there is a packet available, the |
// packet header should be supplied in |packet_header|; otherwise it should |
// be NULL. The mode resulting form the last call to NetEqImpl::GetAudio is |
// supplied in |prev_mode|. If there is a DTMF event to play, |play_dtmf| |
// should be set to true. The output variable |reset_decoder| will be set to |
// true if a reset is required; otherwise it is left unchanged (i.e., it can |
// remain true if it was true before the call). |
// Should be implemented by derived classes. |
virtual Operations GetDecisionSpecialized(const SyncBuffer& sync_buffer, |
const Expand& expand, |
size_t decoder_frame_length, |
- const RTPHeader* packet_header, |
+ const Packet* next_packet, |
Modes prev_mode, |
bool play_dtmf, |
bool* reset_decoder, |
@@ -66,19 +66,18 @@ class DecisionLogic { |
// Returns the operation that should be done next. |sync_buffer| and |expand| |
// are provided for reference. |decoder_frame_length| is the number of samples |
- // obtained from the last decoded frame. If there is a packet available, the |
- // packet header should be supplied in |packet_header|; otherwise it should |
- // be NULL. The mode resulting form the last call to NetEqImpl::GetAudio is |
- // supplied in |prev_mode|. If there is a DTMF event to play, |play_dtmf| |
- // should be set to true. The output variable |reset_decoder| will be set to |
- // true if a reset is required; otherwise it is left unchanged (i.e., it can |
- // remain true if it was true before the call). |
- // This method end with calling GetDecisionSpecialized to get the actual |
- // return value. |
+ // obtained from the last decoded frame. If there is a packet available, it |
+ // should be supplied in |next_packet|; otherwise it should be NULL. The mode |
+ // resulting from the last call to NetEqImpl::GetAudio is supplied in |
+ // |prev_mode|. If there is a DTMF event to play, |play_dtmf| should be set to |
+ // true. The output variable |reset_decoder| will be set to true if a reset is |
+ // required; otherwise it is left unchanged (i.e., it can remain true if it |
+ // was true before the call). This method end with calling |
+ // GetDecisionSpecialized to get the actual return value. |
Operations GetDecision(const SyncBuffer& sync_buffer, |
const Expand& expand, |
@@ -124,18 +123,17 @@ class DecisionLogic { |
// Returns the operation that should be done next. |sync_buffer| and |expand| |
// are provided for reference. |decoder_frame_length| is the number of samples |
- // obtained from the last decoded frame. If there is a packet available, the |
- // packet header should be supplied in |packet_header|; otherwise it should |
- // be NULL. The mode resulting form the last call to NetEqImpl::GetAudio is |
- // supplied in |prev_mode|. If there is a DTMF event to play, |play_dtmf| |
- // should be set to true. The output variable |reset_decoder| will be set to |
- // true if a reset is required; otherwise it is left unchanged (i.e., it can |
- // remain true if it was true before the call). |
- // Should be implemented by derived classes. |
+ // obtained from the last decoded frame. If there is a packet available, it |
+ // should be supplied in |next_packet|; otherwise it should be NULL. The mode |
+ // resulting from the last call to NetEqImpl::GetAudio is supplied in |
+ // |prev_mode|. If there is a DTMF event to play, |play_dtmf| should be set to |
+ // true. The output variable |reset_decoder| will be set to true if a reset is |
+ // required; otherwise it is left unchanged (i.e., it can remain true if it |
+ // was true before the call). Should be implemented by derived classes. |
virtual Operations GetDecisionSpecialized(const SyncBuffer& sync_buffer, |
const Expand& expand, |